@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000-2014 Free Software Foundation, Inc.
+ * Copyright (C) 2000-2021 Free Software Foundation, Inc.
  *
  * This file is part of LIBTASN1.
  *
@@ -20,15 +20,23 @@
  */
 
 #ifndef _ELEMENT_H
-#define _ELEMENT_H
+# define _ELEMENT_H
 
 
-int _asn1_append_sequence_set (asn1_node node, asn1_node *pcached);
+struct node_tail_cache_st
+{
+  asn1_node head;		/* the first element of the sequence */
+  asn1_node tail;
+};
+
+int _asn1_append_sequence_set (asn1_node node,
+			       struct node_tail_cache_st *pcached);
 
 int _asn1_convert_integer (const unsigned char *value,
 			   unsigned char *value_out,
 			   int value_out_size, int *len);
 
-void _asn1_hierarchical_name (asn1_node node, char *name, int name_size);
+void _asn1_hierarchical_name (asn1_node_const node, char *name,
+			      int name_size);
 
 #endif
